/*
  	Returning_and_passing_parameters_GUI.js
    Purpose: show how to pass and return parameters when creating BrainVoyager QX 2.1 scripts with a graphical user interface (GUI).
    Functionality: calculate the size of a smoothing kernel in mm, using the information about the kernel size in pixels and the pixel size, 
    information stored in different functions. The information in widget 'dspboxPixSize' is communicated to function getKernelInMm(kernelInPixels) 
    via the kernelInPixels argument. The calculation is carried out in the getKernelInMm() function and communicated to the function 
    calculateKernel(), where the result is placed on line edit widget 'lneditKernelsize'.
  	Difference with non-GUI script: when using a function, use 'this.' when invoking the function, 
  	if the function does contain references to graphical elements (widgets). For example: this.getKernelInPixels(); 
	HB, BI, 2010.
*/

var scriptObj = new Object; 
scriptObj.scriptNameForUser = "Returning and passing parameters (with interface)"; 
scriptObj.dialogFileName = "Returning_and_passing_parameters_GUI.ui"; 
scriptObj.dialogAccessName = "dlgPassingParams"; 

BrainVoyagerQX.PrintToLog("Starting script to calculate smoothing kernel size…");

scriptObj.calculateKernel = function() { 

	BrainVoyagerQX.PrintToLog("Calculate...");
    	var kernelInPixels = this.getKernelInPixels(); 	// function takes no parameters, returns one parameter
    	var kernelInMm = this.getKernelInMm(kernelInPixels); // function takes 1 parameter, returns one parameter
    	this.dlgPassingParams.lneditKernelsizeMm.text = kernelInMm;
	BrainVoyagerQX.PrintToLog("Kernel in mm: " + kernelInMm);
}

scriptObj.getKernelInPixels = function() {

	BrainVoyagerQX.PrintToLog("Get kernel in pixel size...");
	var pixelsize = this.dlgPassingParams.spboxKernelSizePix.value;    
	return pixelsize;
}

scriptObj.getKernelInMm = function(kernelInPixels) {

	BrainVoyagerQX.PrintToLog("Get kernel in mm...");
	var pixelsize = this.dlgPassingParams.dspboxPixSize.value;
	var kernelInMm = pixelsize * kernelInPixels;
   	return kernelInMm;
}

scriptObj.initDlg = function() { 
	this.dlgPassingParams.windowTitle = "Calculate kernel size"; 
	this.dlgPassingParams.btnCalculate.clicked.connect(this, this.calculateKernel); 
}

returnScriptObj = function() { 
	return scriptObj; 
} 
returnScriptObj(); // should be after returnScriptOjb = function()
